<p align="center"><img src="https://github.com/facebookincubator/flowtorch/raw/main/website/static/img/logo.svg" width="200rem" /></p>

[![](https://github.com/facebookincubator/flowtorch/workflows/Python%20package/badge.svg)](https://github.com/facebookincubator/flowtorch/actions?query=workflow%3A%22Python+package%22)

Copyright © Meta Platforms, Inc

This source code is licensed under the MIT license found in the
[LICENSE.txt](https://github.com/facebookincubator/flowtorch/blob/main/LICENSE.txt) file in the root directory of this source tree.

# Overview

FlowTorch is a PyTorch library for learning and sampling from complex probability distributions using a class of methods called [Normalizing Flows](https://arxiv.org/abs/1908.09257).

# Installing

An easy way to get started is to install from source:

    git clone https://github.com/facebookincubator/flowtorch.git
    cd flowtorch
    pip install -e .

# Further Information

We refer you to the [FlowTorch website](https://flowtorch.ai) for more information about installation, using the library, and becoming a contributor. Here is a handy guide:

* [What are normalizing flows?](https://flowtorch.ai/users)
* [How do I install FlowTorch?](https://flowtorch.ai/users/installation)
* [How do I construct and train a distribution?](https://flowtorch.ai/users/start)
* [How do I contribute new normalizing flow methods?](https://flowtorch.ai/dev)
* [Where can I report bugs?](https://github.com/facebookincubator/flowtorch/issues)
* [Where can I ask general questions and make feature requests?](https://github.com/facebookincubator/flowtorch/discussions)
* [What features are planned for the near future?](https://github.com/facebookincubator/flowtorch/projects)
